@@ -33,12 +33,13 @@ struct _GladeEditorProperty {
 	GtkWidget          *check;          /* Check button for optional properties.
 					     */
 
+	GtkWidget          *info;           /* Informational button
+					     */
 
 	gulong              tooltip_id;     /* signal connection id for tooltip changes        */
 	gulong              sensitive_id;   /* signal connection id for sensitivity changes    */
 	gulong              changed_id;     /* signal connection id for value changes          */
 	gulong              enabled_id;     /* signal connection id for enable/disable changes */
-	gulong              closed_id;      /* signal connection id for closing projects       */
 	
 	gboolean            loading;        /* True during glade_editor_property_load calls, this
 					     * is used to avoid feedback from input widgets.
@@ -48,6 +49,16 @@ struct _GladeEditorProperty {
 					     * or skip directly to GladeProperty interface.
 					     * (used for query dialogs).
 					     */
+
+	gboolean            show_info;      /* Whether we should show an informational button
+					     * for this property
+					     */
+
+	GdkColor           *insensitive_colour;	/* For setting insensitive background on   */
+	GdkColor           *normal_colour;      /* labels without setting them insensitive
+						 * (tooltips dont work on insensitive widgets
+						 * at this time)
+						 */
 };
 
 struct _GladeEditorPropertyClass {
@@ -57,6 +68,12 @@ struct _GladeEditorPropertyClass {
 
 	/* private */
 	GtkWidget  *(* create_input)  (GladeEditorProperty *);
+
+	void        (* gtk_doc_search)(GladeEditorProperty *, 
+				       const gchar *,
+				       const gchar *,
+				       const gchar *);
+
 };
 
 
@@ -66,6 +83,10 @@ LIBGLADEUI_API
 GladeEditorProperty *glade_editor_property_new            (GladePropertyClass  *class,
 							   gboolean             use_command);
 LIBGLADEUI_API
+GladeEditorProperty *glade_editor_property_new_from_widget (GladeWidget        *widget,
+							    const gchar        *property,
+							    gboolean            use_command);
+LIBGLADEUI_API
 void                 glade_editor_property_load           (GladeEditorProperty *eprop,
 							   GladeProperty       *property);
 LIBGLADEUI_API
@@ -73,10 +94,9 @@ void                 glade_editor_property_load_by_widget (GladeEditorProperty *
 							   GladeWidget         *widget);
 LIBGLADEUI_API
 gboolean             glade_editor_property_supported      (GParamSpec          *pspec);
-
 LIBGLADEUI_API
-GladeEditorProperty *glade_editor_property_new_from_widget (GladeWidget        *widget,
-							    const gchar        *property,
-							    gboolean            use_command);
+void                 glade_editor_property_show_info      (GladeEditorProperty *eprop);
+LIBGLADEUI_API
+void                 glade_editor_property_hide_info      (GladeEditorProperty *eprop);
 
 #endif // __GLADE_EDITOR_PROPERTY_H__
