@@ -171,6 +171,7 @@ glade_property_class_new (gpointer handle)
 	property_class->translatable = FALSE;
 	property_class->type = GPC_NORMAL;
 	property_class->virtual = TRUE;
+	property_class->transfer_on_paste = FALSE;
 
 	return property_class;
 }
@@ -392,11 +393,13 @@ glade_property_class_make_string_from_object (GladePropertyClass *property_class
 	else if (property_class->pspec->value_type == GTK_TYPE_ADJUSTMENT)
 	{
 		GtkAdjustment *adj = GTK_ADJUSTMENT (object);
-		string = g_strdup_printf ("%lf %lf %lf %lf %lf %lf", 
-					  adj->value, adj->lower, adj->upper, 
-					  adj->step_increment, 
-					  adj->page_increment,
-					  adj->page_size);
+		
+		/* Glade format expects integers */
+		string = g_strdup_printf ("%d %d %d %d %d %d", 
+					  (gint)adj->value, (gint)adj->lower, (gint)adj->upper, 
+					  (gint)adj->step_increment, 
+					  (gint)adj->page_increment,
+					  (gint)adj->page_size);
 	}
 	else if ((gwidget = glade_widget_get_from_gobject (object)) != NULL)
 		string = g_strdup (gwidget->name);
@@ -1625,6 +1628,7 @@ glade_property_class_update_from_node (GladeXmlNode        *node,
 	class->visible  = glade_xml_get_property_boolean (node, GLADE_TAG_VISIBLE,  class->visible);
 	class->ignore   = glade_xml_get_property_boolean (node, GLADE_TAG_IGNORE,   class->ignore);
 	class->resource = glade_xml_get_property_boolean (node, GLADE_TAG_RESOURCE, class->resource);
+	class->transfer_on_paste = glade_xml_get_property_boolean (node, GLADE_TAG_TRANSFER_ON_PASTE, class->transfer_on_paste);
 
 	/* No atk introspection here.
 	 */
