@@ -75,7 +75,7 @@ struct _GladePropertyKlass
 	G_CONST_RETURN gchar *  (* get_tooltip)           (GladeProperty *);
 
 	/* Signals */
-	void             (* value_changed)         (GladeProperty *, GValue *);
+	void             (* value_changed)         (GladeProperty *, GValue *, GValue *);
 	void             (* tooltip_changed)       (GladeProperty *, const gchar *);
 };
 
@@ -95,7 +95,7 @@ LIBGLADEUI_API
 gboolean                glade_property_default               (GladeProperty      *property);
 LIBGLADEUI_API
 gboolean                glade_property_equals_value          (GladeProperty      *property, 
-							      GValue             *value);
+							      const GValue       *value);
 LIBGLADEUI_API
 gboolean                glade_property_equals                (GladeProperty      *property, 
 							      ...);
@@ -170,6 +170,13 @@ void                    glade_property_i18n_set_has_context  (GladeProperty
 LIBGLADEUI_API
 gboolean                glade_property_i18n_get_has_context  (GladeProperty      *property);
 
+LIBGLADEUI_API
+void                    glade_property_push_superuser        (void);
+LIBGLADEUI_API
+void                    glade_property_pop_superuser         (void);
+LIBGLADEUI_API
+gboolean                glade_property_superuser             (void);
+
 G_END_DECLS
 
 #endif /* __GLADE_PROPERTY_H__ */
