@@ -695,7 +695,7 @@ glade_xml_doc_get_root (GladeXmlDoc *doc)
 }
 
 gchar *
-alloc_string(GladeInterface *interface, const gchar *string)
+glade_xml_alloc_string(GladeInterface *interface, const gchar *string)
 {
     gchar *s;
 
@@ -709,7 +709,7 @@ alloc_string(GladeInterface *interface, const gchar *string)
 }
 
 gchar *
-alloc_propname(GladeInterface *interface, const gchar *string)
+glade_xml_alloc_propname(GladeInterface *interface, const gchar *string)
 {
     static GString *norm_str;
     guint i;
@@ -724,7 +724,7 @@ alloc_propname(GladeInterface *interface, const gchar *string)
 	if (norm_str->str[i] == '-')
 	    norm_str->str[i] = '_';
 
-    return alloc_string(interface, norm_str->str);
+    return glade_xml_alloc_string(interface, norm_str->str);
 }
 
 
@@ -734,9 +734,12 @@ glade_xml_load_sym_from_node (GladeXmlNode     *node_in,
 			      gchar            *tagname,
 			      gpointer         *sym_location)
 {
-	xmlNodePtr node = (xmlNodePtr) node_in;
+	static GModule *self = NULL;
 	gchar *buff;
 
+	if (!self) 
+		self = g_module_open (NULL, 0);
+
 	if ((buff = glade_xml_get_value_string (node_in, tagname)) != NULL)
 	{
 		if (!module)
@@ -757,10 +760,13 @@ glade_xml_load_sym_from_node (GladeXmlNode     *node_in,
 		 * I dont know who wrote the above in glade-property-class.c, but
 		 * its a good point... makeing a bugzilla entry.
 		 *  -Tristan
+		 *
+		 * XXX http://bugzilla.gnome.org/show_bug.cgi?id=331797
 		 */
 		if (!g_module_symbol (module, buff, sym_location))
-			g_warning ("Could not find %s in %s\n",
-				   buff, g_module_name (module));
+			if (!g_module_symbol (self, buff, sym_location))
+				g_warning ("Could not find %s in %s or in global namespace\n",
+					   buff, g_module_name (module));
 		g_free (buff);
 	}
 }
